# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_cdn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_cdn.proto\x12\x1foak9.tython.azure.microsoft_cdn\x1a\x13shared/shared.proto\"\xc4\x04\n\rMicrosoft_Cdn\x12q\n%cdn_web_application_firewall_policies\x18\x01 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_cdn.CdnWebApplicationFirewallPolicies\x12;\n\x08profiles\x18\x02 \x01(\x0b\x32).oak9.tython.azure.microsoft_cdn.Profiles\x12N\n\x12profiles_endpoints\x18\x03 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ProfilesEndpoints\x12j\n!profiles_endpoints_custom_domains\x18\x04 \x03(\x0b\x32?.oak9.tython.azure.microsoft_cdn.ProfilesEndpointsCustomDomains\x12h\n profiles_endpoints_origin_groups\x18\x05 \x03(\x0b\x32>.oak9.tython.azure.microsoft_cdn.ProfilesEndpointsOriginGroups\x12]\n\x1aprofiles_endpoints_origins\x18\x06 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.ProfilesEndpointsOrigins\"\xb0\x01\n\x18ProfilesSecurityPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12M\n\nparameters\x18\x03 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.SecurityPolicyParameters\"(\n\x18SecurityPolicyParameters\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x9f\x01\n\x0fProfilesSecrets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\nparameters\x18\x03 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_cdn.SecretParameters\" \n\x10SecretParameters\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa3\x02\n\x15ProfilesRuleSetsRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_cdn.DeliveryRuleAction1\x12J\n\nconditions\x18\x04 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.DeliveryRuleCondition\x12!\n\x19match_processing_behavior\x18\x05 \x01(\t\x12\r\n\x05order\x18\x06 \x01(\x05\"\xb3\x01\n\x10ProfilesRuleSets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x18profiles_rule_sets_rules\x18\x03 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.ProfilesRuleSetsRules\"\xab\x04\n\x1bProfilesOriginGroupsOrigins\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\x0c\x61zure_origin\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x15\n\renabled_state\x18\x04 \x01(\t\x12&\n\x1e\x65nforce_certificate_name_check\x18\x05 \x01(\x08\x12\x11\n\thost_name\x18\x06 \x01(\t\x12\x11\n\thttp_port\x18\x07 \x01(\x05\x12\x12\n\nhttps_port\x18\x08 \x01(\x05\x12\x1a\n\x12origin_host_header\x18\t \x01(\t\x12\x10\n\x08priority\x18\n \x01(\x05\x12\x81\x01\n\x1cshared_private_link_resource\x18\x0b \x03(\x0b\x32[.oak9.tython.azure.microsoft_cdn.ProfilesOriginGroupsOrigins.SharedPrivateLinkResourceEntry\x12\x0e\n\x06weight\x18\x0c \x01(\x05\x1a@\n\x1eSharedPrivateLinkResourceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x04\n\x14ProfilesOriginGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x15health_probe_settings\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.HealthProbeParameters\x12\x61\n\x17load_balancing_settings\x18\x04 \x01(\x0b\x32@.oak9.tython.azure.microsoft_cdn.LoadBalancingSettingsParameters\x12\x88\x01\n2response_based_afd_origin_error_detection_settings\x18\x05 \x01(\x0b\x32L.oak9.tython.azure.microsoft_cdn.ResponseBasedOriginErrorDetectionParameters\x12\x1e\n\x16session_affinity_state\x18\x06 \x01(\t\x12\x46\n>traffic_restoration_time_to_healed_or_new_endpoints_in_minutes\x18\x07 \x01(\x05\x12\x64\n\x1eprofiles_origin_groups_origins\x18\x08 \x03(\x0b\x32<.oak9.tython.azure.microsoft_cdn.ProfilesOriginGroupsOrigins\"\x87\x01\n\x1fLoadBalancingSettingsParameters\x12*\n\"additional_latency_in_milliseconds\x18\x01 \x01(\x05\x12\x13\n\x0bsample_size\x18\x02 \x01(\x05\x12#\n\x1bsuccessful_samples_required\x18\x03 \x01(\x05\"\xee\x02\n\x18ProfilesEndpointsOrigins\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x11\n\thttp_port\x18\x05 \x01(\x05\x12\x12\n\nhttps_port\x18\x06 \x01(\x05\x12\x1a\n\x12origin_host_header\x18\x07 \x01(\t\x12\x10\n\x08priority\x18\x08 \x01(\x05\x12\x1a\n\x12private_link_alias\x18\t \x01(\t\x12%\n\x1dprivate_link_approval_message\x18\n \x01(\t\x12\x1d\n\x15private_link_location\x18\x0b \x01(\t\x12 \n\x18private_link_resource_id\x18\x0c \x01(\t\x12\x0e\n\x06weight\x18\r \x01(\x05\"\xd1\x03\n\x1dProfilesEndpointsOriginGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x15health_probe_settings\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.HealthProbeParameters\x12\x43\n\x07origins\x18\x04 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x84\x01\n.response_based_origin_error_detection_settings\x18\x05 \x01(\x0b\x32L.oak9.tython.azure.microsoft_cdn.ResponseBasedOriginErrorDetectionParameters\x12\x46\n>traffic_restoration_time_to_healed_or_new_endpoints_in_minutes\x18\x06 \x01(\x05\"z\n\x1eProfilesEndpointsCustomDomains\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\thost_name\x18\x03 \x01(\t\"\xd4\x08\n\x11ProfilesEndpoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12!\n\x19\x63ontent_types_to_compress\x18\x04 \x03(\t\x12P\n\x14\x64\x65\x66\x61ult_origin_group\x18\x05 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12j\n\x0f\x64\x65livery_policy\x18\x06 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_cdn.EndpointPropertiesUpdateParametersDeliveryPolicy\x12?\n\x0bgeo_filters\x18\x07 \x03(\x0b\x32*.oak9.tython.azure.microsoft_cdn.GeoFilter\x12\x1e\n\x16is_compression_enabled\x18\x08 \x01(\x08\x12\x17\n\x0fis_http_allowed\x18\t \x01(\x08\x12\x18\n\x10is_https_allowed\x18\n \x01(\x08\x12\x19\n\x11optimization_type\x18\x0b \x01(\t\x12N\n\rorigin_groups\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_cdn.DeepCreatedOriginGroup\x12\x1a\n\x12origin_host_header\x18\r \x01(\t\x12\x13\n\x0borigin_path\x18\x0e \x01(\t\x12\x43\n\x07origins\x18\x0f \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.DeepCreatedOrigin\x12\x12\n\nprobe_path\x18\x10 \x01(\t\x12%\n\x1dquery_string_caching_behavior\x18\x11 \x01(\t\x12H\n\x10url_signing_keys\x18\x12 \x03(\x0b\x32..oak9.tython.azure.microsoft_cdn.UrlSigningKey\x12\x91\x01\n$web_application_firewall_policy_link\x18\x13 \x01(\x0b\x32\x63.oak9.tython.azure.microsoft_cdn.EndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink\x12J\n\x04tags\x18\x14 \x03(\x0b\x32<.oak9.tython.azure.microsoft_cdn.ProfilesEndpoints.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\nBEndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink\x12\n\n\x02id\x18\x01 \x01(\t\"}\n\rUrlSigningKey\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\\\n\x15key_source_parameters\x18\x02 \x01(\x0b\x32=.oak9.tython.azure.microsoft_cdn.KeyVaultSigningKeyParameters\"\xa8\x01\n\x1cKeyVaultSigningKeyParameters\x12\x1b\n\x13resource_group_name\x18\x01 \x01(\t\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\x12\x16\n\x0esecret_version\x18\x03 \x01(\t\x12\x17\n\x0fsubscription_id\x18\x04 \x01(\t\x12\x11\n\ttype_name\x18\x05 \x01(\t\x12\x12\n\nvault_name\x18\x06 \x01(\t\"\xae\x02\n\x11\x44\x65\x65pCreatedOrigin\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x11\n\thost_name\x18\x03 \x01(\t\x12\x11\n\thttp_port\x18\x04 \x01(\x05\x12\x12\n\nhttps_port\x18\x05 \x01(\x05\x12\x1a\n\x12origin_host_header\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\x05\x12\x1a\n\x12private_link_alias\x18\x08 \x01(\t\x12%\n\x1dprivate_link_approval_message\x18\t \x01(\t\x12\x1d\n\x15private_link_location\x18\n \x01(\t\x12 \n\x18private_link_resource_id\x18\x0b \x01(\t\x12\x0e\n\x06weight\x18\x0c \x01(\x05\"\x91\x03\n\x16\x44\x65\x65pCreatedOriginGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12U\n\x15health_probe_settings\x18\x02 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.HealthProbeParameters\x12\x43\n\x07origins\x18\x03 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x84\x01\n.response_based_origin_error_detection_settings\x18\x04 \x01(\x0b\x32L.oak9.tython.azure.microsoft_cdn.ResponseBasedOriginErrorDetectionParameters\x12\x46\n>traffic_restoration_time_to_healed_or_new_endpoints_in_minutes\x18\x05 \x01(\x05\"\xe6\x01\n+ResponseBasedOriginErrorDetectionParameters\x12T\n\x11http_error_ranges\x18\x01 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.HttpErrorRangeParameters\x12+\n#response_based_detected_error_types\x18\x02 \x01(\t\x12\x34\n,response_based_failover_threshold_percentage\x18\x03 \x01(\x05\"6\n\x18HttpErrorRangeParameters\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\"\x82\x01\n\x15HealthProbeParameters\x12!\n\x19probe_interval_in_seconds\x18\x01 \x01(\x05\x12\x12\n\nprobe_path\x18\x02 \x01(\t\x12\x16\n\x0eprobe_protocol\x18\x03 \x01(\t\x12\x1a\n\x12probe_request_type\x18\x04 \x01(\t\"I\n\tGeoFilter\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\rcountry_codes\x18\x02 \x03(\t\x12\x15\n\rrelative_path\x18\x03 \x01(\t\"\x85\x01\n0EndpointPropertiesUpdateParametersDeliveryPolicy\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12<\n\x05rules\x18\x02 \x03(\x0b\x32-.oak9.tython.azure.microsoft_cdn.DeliveryRule\"\xbe\x01\n\x0c\x44\x65liveryRule\x12\x45\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_cdn.DeliveryRuleAction1\x12J\n\nconditions\x18\x02 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.DeliveryRuleCondition\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05order\x18\x04 \x01(\x05\"%\n\x15\x44\x65liveryRuleCondition\x12\x0c\n\x04name\x18\x01 \x01(\t\"#\n\x13\x44\x65liveryRuleAction1\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf3\x02\n\x15ProfilesCustomDomains\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\x0e\x61zure_dns_zone\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x63\n\'pre_validated_custom_domain_resource_id\x18\x05 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12O\n\x0ctls_settings\x18\x06 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.AFDDomainHttpsParameters\"\x95\x01\n\x18\x41\x46\x44\x44omainHttpsParameters\x12\x18\n\x10\x63\x65rtificate_type\x18\x01 \x01(\t\x12\x1b\n\x13minimum_tls_version\x18\x02 \x01(\t\x12\x42\n\x06secret\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\"\xdc\x04\n\x1aProfilesAfdEndpointsRoutes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x13\x63\x61\x63he_configuration\x18\x03 \x01(\x0b\x32;.oak9.tython.azure.microsoft_cdn.AfdRouteCacheConfiguration\x12S\n\x0e\x63ustom_domains\x18\x04 \x03(\x0b\x32;.oak9.tython.azure.microsoft_cdn.ActivatedResourceReference\x12\x15\n\renabled_state\x18\x05 \x01(\t\x12\x1b\n\x13\x66orwarding_protocol\x18\x06 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x07 \x01(\t\x12\x1e\n\x16link_to_default_domain\x18\x08 \x01(\t\x12H\n\x0corigin_group\x18\t \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x13\n\x0borigin_path\x18\n \x01(\t\x12\x19\n\x11patterns_to_match\x18\x0b \x03(\t\x12\x45\n\trule_sets\x18\x0c \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x1b\n\x13supported_protocols\x18\r \x03(\t\"\x1f\n\x11ResourceReference\x12\n\n\x02id\x18\x01 \x01(\t\"(\n\x1a\x41\x63tivatedResourceReference\x12\n\n\x02id\x18\x01 \x01(\t\"\x8d\x02\n\x1a\x41\x66\x64RouteCacheConfiguration\x12r\n\x14\x63ompression_settings\x18\x01 \x03(\x0b\x32T.oak9.tython.azure.microsoft_cdn.AfdRouteCacheConfiguration.CompressionSettingsEntry\x12\x18\n\x10query_parameters\x18\x02 \x01(\t\x12%\n\x1dquery_string_caching_behavior\x18\x03 \x01(\t\x1a:\n\x18\x43ompressionSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x03\n\x14ProfilesAfdEndpoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\renabled_state\x18\x04 \x01(\t\x12\'\n\x1forigin_response_timeout_seconds\x18\x05 \x01(\x05\x12M\n\x04tags\x18\x06 \x03(\x0b\x32?.oak9.tython.azure.microsoft_cdn.ProfilesAfdEndpoints.TagsEntry\x12\x62\n\x1dprofiles_afd_endpoints_routes\x18\x07 \x03(\x0b\x32;.oak9.tython.azure.microsoft_cdn.ProfilesAfdEndpointsRoutes\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x06\n\x08Profiles\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12I\n\x08identity\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_cdn.ManagedServiceIdentity\x12\'\n\x1forigin_response_timeout_seconds\x18\x05 \x01(\x05\x12\x31\n\x03sku\x18\x06 \x01(\x0b\x32$.oak9.tython.azure.microsoft_cdn.Sku\x12\x41\n\x04tags\x18\x07 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_cdn.Profiles.TagsEntry\x12W\n\x17profiles_custom_domains\x18\x08 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.ProfilesCustomDomains\x12U\n\x16profiles_afd_endpoints\x18\t \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_cdn.ProfilesAfdEndpoints\x12U\n\x16profiles_origin_groups\x18\n \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_cdn.ProfilesOriginGroups\x12M\n\x12profiles_rule_sets\x18\x0b \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_cdn.ProfilesRuleSets\x12]\n\x1aprofiles_security_policies\x18\x0c \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.ProfilesSecurityPolicies\x12J\n\x10profiles_secrets\x18\r \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_cdn.ProfilesSecrets\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"&\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\"\xf1\x04\n!CdnWebApplicationFirewallPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x45\n\x0c\x63ustom_rules\x18\x05 \x01(\x0b\x32/.oak9.tython.azure.microsoft_cdn.CustomRuleList\x12J\n\rmanaged_rules\x18\x06 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_cdn.ManagedRuleSetList\x12H\n\x0fpolicy_settings\x18\x07 \x01(\x0b\x32/.oak9.tython.azure.microsoft_cdn.PolicySettings\x12L\n\x10rate_limit_rules\x18\x08 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.RateLimitRuleList\x12\x31\n\x03sku\x18\t \x01(\x0b\x32$.oak9.tython.azure.microsoft_cdn.Sku\x12Z\n\x04tags\x18\n \x03(\x0b\x32L.oak9.tython.azure.microsoft_cdn.CdnWebApplicationFirewallPolicies.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x13\n\x03Sku\x12\x0c\n\x04name\x18\x01 \x01(\t\"R\n\x11RateLimitRuleList\x12=\n\x05rules\x18\x01 \x03(\x0b\x32..oak9.tython.azure.microsoft_cdn.RateLimitRule\"\xe7\x01\n\rRateLimitRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12I\n\x10match_conditions\x18\x03 \x03(\x0b\x32/.oak9.tython.azure.microsoft_cdn.MatchCondition\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12&\n\x1erate_limit_duration_in_minutes\x18\x06 \x01(\x05\x12\x1c\n\x14rate_limit_threshold\x18\x07 \x01(\x05\"\xb2\x01\n\x0ePolicySettings\x12*\n\"default_custom_block_response_body\x18\x01 \x01(\t\x12\x31\n)default_custom_block_response_status_code\x18\x02 \x01(\x05\x12\x1c\n\x14\x64\x65\x66\x61ult_redirect_url\x18\x03 \x01(\t\x12\x15\n\renabled_state\x18\x04 \x01(\t\x12\x0c\n\x04mode\x18\x05 \x01(\t\"`\n\x12ManagedRuleSetList\x12J\n\x11managed_rule_sets\x18\x01 \x03(\x0b\x32/.oak9.tython.azure.microsoft_cdn.ManagedRuleSet\"\xb1\x01\n\x0eManagedRuleSet\x12\x15\n\ranomaly_score\x18\x01 \x01(\x05\x12W\n\x14rule_group_overrides\x18\x02 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.ManagedRuleGroupOverride\x12\x15\n\rrule_set_type\x18\x03 \x01(\t\x12\x18\n\x10rule_set_version\x18\x04 \x01(\t\"x\n\x18ManagedRuleGroupOverride\x12\x17\n\x0frule_group_name\x18\x01 \x01(\t\x12\x43\n\x05rules\x18\x02 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_cdn.ManagedRuleOverride\"M\n\x13ManagedRuleOverride\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12\x0f\n\x07rule_id\x18\x03 \x01(\t\"L\n\x0e\x43ustomRuleList\x12:\n\x05rules\x18\x01 \x03(\x0b\x32+.oak9.tython.azure.microsoft_cdn.CustomRule\"\x9e\x01\n\nCustomRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12I\n\x10match_conditions\x18\x03 \x03(\x0b\x32/.oak9.tython.azure.microsoft_cdn.MatchCondition\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\"\x8f\x01\n\x0eMatchCondition\x12\x13\n\x0bmatch_value\x18\x01 \x03(\t\x12\x16\n\x0ematch_variable\x18\x02 \x01(\t\x12\x18\n\x10negate_condition\x18\x03 \x01(\x08\x12\x10\n\x08operator\x18\x04 \x01(\t\x12\x10\n\x08selector\x18\x05 \x01(\t\x12\x12\n\ntransforms\x18\x06 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_cdn_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._options = None
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._serialized_options = b'8\001'
  _PROFILESENDPOINTS_TAGSENTRY._options = None
  _PROFILESENDPOINTS_TAGSENTRY._serialized_options = b'8\001'
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._options = None
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._serialized_options = b'8\001'
  _PROFILESAFDENDPOINTS_TAGSENTRY._options = None
  _PROFILESAFDENDPOINTS_TAGSENTRY._serialized_options = b'8\001'
  _PROFILES_TAGSENTRY._options = None
  _PROFILES_TAGSENTRY._serialized_options = b'8\001'
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._options = None
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_CDN._serialized_start=90
  _MICROSOFT_CDN._serialized_end=670
  _PROFILESSECURITYPOLICIES._serialized_start=673
  _PROFILESSECURITYPOLICIES._serialized_end=849
  _SECURITYPOLICYPARAMETERS._serialized_start=851
  _SECURITYPOLICYPARAMETERS._serialized_end=891
  _PROFILESSECRETS._serialized_start=894
  _PROFILESSECRETS._serialized_end=1053
  _SECRETPARAMETERS._serialized_start=1055
  _SECRETPARAMETERS._serialized_end=1087
  _PROFILESRULESETSRULES._serialized_start=1090
  _PROFILESRULESETSRULES._serialized_end=1381
  _PROFILESRULESETS._serialized_start=1384
  _PROFILESRULESETS._serialized_end=1563
  _PROFILESORIGINGROUPSORIGINS._serialized_start=1566
  _PROFILESORIGINGROUPSORIGINS._serialized_end=2121
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._serialized_start=2057
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._serialized_end=2121
  _PROFILESORIGINGROUPS._serialized_start=2124
  _PROFILESORIGINGROUPS._serialized_end=2748
  _LOADBALANCINGSETTINGSPARAMETERS._serialized_start=2751
  _LOADBALANCINGSETTINGSPARAMETERS._serialized_end=2886
  _PROFILESENDPOINTSORIGINS._serialized_start=2889
  _PROFILESENDPOINTSORIGINS._serialized_end=3255
  _PROFILESENDPOINTSORIGINGROUPS._serialized_start=3258
  _PROFILESENDPOINTSORIGINGROUPS._serialized_end=3723
  _PROFILESENDPOINTSCUSTOMDOMAINS._serialized_start=3725
  _PROFILESENDPOINTSCUSTOMDOMAINS._serialized_end=3847
  _PROFILESENDPOINTS._serialized_start=3850
  _PROFILESENDPOINTS._serialized_end=4958
  _PROFILESENDPOINTS_TAGSENTRY._serialized_start=4915
  _PROFILESENDPOINTS_TAGSENTRY._serialized_end=4958
  _ENDPOINTPROPERTIESUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_start=4960
  _ENDPOINTPROPERTIESUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_end=5040
  _URLSIGNINGKEY._serialized_start=5042
  _URLSIGNINGKEY._serialized_end=5167
  _KEYVAULTSIGNINGKEYPARAMETERS._serialized_start=5170
  _KEYVAULTSIGNINGKEYPARAMETERS._serialized_end=5338
  _DEEPCREATEDORIGIN._serialized_start=5341
  _DEEPCREATEDORIGIN._serialized_end=5643
  _DEEPCREATEDORIGINGROUP._serialized_start=5646
  _DEEPCREATEDORIGINGROUP._serialized_end=6047
  _RESPONSEBASEDORIGINERRORDETECTIONPARAMETERS._serialized_start=6050
  _RESPONSEBASEDORIGINERRORDETECTIONPARAMETERS._serialized_end=6280
  _HTTPERRORRANGEPARAMETERS._serialized_start=6282
  _HTTPERRORRANGEPARAMETERS._serialized_end=6336
  _HEALTHPROBEPARAMETERS._serialized_start=6339
  _HEALTHPROBEPARAMETERS._serialized_end=6469
  _GEOFILTER._serialized_start=6471
  _GEOFILTER._serialized_end=6544
  _ENDPOINTPROPERTIESUPDATEPARAMETERSDELIVERYPOLICY._serialized_start=6547
  _ENDPOINTPROPERTIESUPDATEPARAMETERSDELIVERYPOLICY._serialized_end=6680
  _DELIVERYRULE._serialized_start=6683
  _DELIVERYRULE._serialized_end=6873
  _DELIVERYRULECONDITION._serialized_start=6875
  _DELIVERYRULECONDITION._serialized_end=6912
  _DELIVERYRULEACTION1._serialized_start=6914
  _DELIVERYRULEACTION1._serialized_end=6949
  _PROFILESCUSTOMDOMAINS._serialized_start=6952
  _PROFILESCUSTOMDOMAINS._serialized_end=7323
  _AFDDOMAINHTTPSPARAMETERS._serialized_start=7326
  _AFDDOMAINHTTPSPARAMETERS._serialized_end=7475
  _PROFILESAFDENDPOINTSROUTES._serialized_start=7478
  _PROFILESAFDENDPOINTSROUTES._serialized_end=8082
  _RESOURCEREFERENCE._serialized_start=8084
  _RESOURCEREFERENCE._serialized_end=8115
  _ACTIVATEDRESOURCEREFERENCE._serialized_start=8117
  _ACTIVATEDRESOURCEREFERENCE._serialized_end=8157
  _AFDROUTECACHECONFIGURATION._serialized_start=8160
  _AFDROUTECACHECONFIGURATION._serialized_end=8429
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._serialized_start=8371
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._serialized_end=8429
  _PROFILESAFDENDPOINTS._serialized_start=8432
  _PROFILESAFDENDPOINTS._serialized_end=8831
  _PROFILESAFDENDPOINTS_TAGSENTRY._serialized_start=4915
  _PROFILESAFDENDPOINTS_TAGSENTRY._serialized_end=4958
  _PROFILES._serialized_start=8834
  _PROFILES._serialized_end=9725
  _PROFILES_TAGSENTRY._serialized_start=4915
  _PROFILES_TAGSENTRY._serialized_end=4958
  _MANAGEDSERVICEIDENTITY._serialized_start=9727
  _MANAGEDSERVICEIDENTITY._serialized_end=9765
  _CDNWEBAPPLICATIONFIREWALLPOLICIES._serialized_start=9768
  _CDNWEBAPPLICATIONFIREWALLPOLICIES._serialized_end=10393
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_start=4915
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_end=4958
  _SKU._serialized_start=10395
  _SKU._serialized_end=10414
  _RATELIMITRULELIST._serialized_start=10416
  _RATELIMITRULELIST._serialized_end=10498
  _RATELIMITRULE._serialized_start=10501
  _RATELIMITRULE._serialized_end=10732
  _POLICYSETTINGS._serialized_start=10735
  _POLICYSETTINGS._serialized_end=10913
  _MANAGEDRULESETLIST._serialized_start=10915
  _MANAGEDRULESETLIST._serialized_end=11011
  _MANAGEDRULESET._serialized_start=11014
  _MANAGEDRULESET._serialized_end=11191
  _MANAGEDRULEGROUPOVERRIDE._serialized_start=11193
  _MANAGEDRULEGROUPOVERRIDE._serialized_end=11313
  _MANAGEDRULEOVERRIDE._serialized_start=11315
  _MANAGEDRULEOVERRIDE._serialized_end=11392
  _CUSTOMRULELIST._serialized_start=11394
  _CUSTOMRULELIST._serialized_end=11470
  _CUSTOMRULE._serialized_start=11473
  _CUSTOMRULE._serialized_end=11631
  _MATCHCONDITION._serialized_start=11634
  _MATCHCONDITION._serialized_end=11777
# @@protoc_insertion_point(module_scope)



import uuid
from models.shared.shared_pb2 import Blueprint as BP
from models.shared.shared_pb2 import ValidationMetaInfo
from models.shared.shared_pb2 import Graph, VertexType, Vertex
from models.shared.shared_pb2 import Context as Ctx
from dataclasses import dataclass, field
from enum import Enum, unique
from typing import List, Tuple, ClassVar, Callable, Dict, Union, Set, Any
from colorama import Fore, Style


ValidationFunction = Callable[[any], any]


@unique
class Capabilities(Enum):
    ACCESS_ENFORCEMENT = (
        'Oak9',
        'AE',
        2,
        [
            # TODO: (immutableT) Add the remaining ones.
            # This CR has many check functions, but many are stubs.
            # Come back here once we remove un-implemented checks.
            'check_access_policy_enforcement',
        ])
    APPLICATION_LAYER_ENCRYPTION = ('Oak9', 'DAR', 2, ['check_application_layer_encryption'])
    ASSET_INVENTORY = ('Oak9', 'AI', 1, ['check_asset_inventory'])
    AUTHENTICATION = ('Oak9', 'IA', 1, ['check_identification_and_authentication'])
    AUTHENTICATION_PROTECTION = ('Oak9', 'IA', 2, ['check_protect_authenticators'])
    BACKUP = ('Oak9', 'BR', 2, ['check_backups'])
    DATA_ENCRYPTION_AT_REST = ('Oak9', 'DAR', 1, ['check_transparent_data_encryption'])
    DATA_MINIMIZATION = ('Oak9', 'DM', 1, ['check_data_minimization_enabled'])
    DATA_SANITIZATION = ('Oak9', 'DAR', 4, ['check_securely_remove_data'])
    DENIAL_OF_SERVICE = ('Oak9', 'DOS', 1, ['check_load_balancing', 'check_ip_whitelisting'])
    FIREWALLS = ('Oak9', 'IFE', 1, ['check_firewalls'])
    HARDENING = ('Oak9', 'CM', 1, ['check_hardening'])
    HIGH_AVAILABILITY = ('Oak9', 'BR', 1, ['check_auto_scaling', 'check_high_availability'])
    IDENTIFICATION_AND_AUTHORIZATION = ('Oak9', 'IA', 1, [])
    IDENTITY_LIFECYCLE = ('Oak9', 'ILM', 1, ['check_identity_lifecycle_management'])
    INFORMATION_SYSTEMS_ENFORCING_NETWORK_ACCESS = ('Oak9', 'IFE', 10, ['check_subnet_isolation_enabled'])
    KEY_MANAGEMENT = ('Oak9', 'KM', 1, ['check_protect_cryptographic_keys'])
    LOGGING = ('Oak9', 'AA', 2, ['check_logging', 'check_log_integrity'])
    NETWORK_INFORMATION_FLOW_ENFORCEMENT = ('Oak9', 'IFE', 9, ['check_subnet_isolation_enabled'])
    PRIVILEGED_ACCESS_MANAGEMENT = ('Oak9', 'AE', 3, ['check_privileged_access_management'])
    ROLE_BASED_ACCESS_CONTROL = ('Oak9', 'ILM', 2, ['check_role_based_access_control'])
    SESSION_MANAGEMENT = ('Oak9', 'AE', 1, ['check_session_management'])
    TLS = ('Oak9', 'DIT', 1, ['check_tls', 'check_destination_authentication', 'check_source_authentication'])

    def __init__(self, company: str, category: str, index: int, validation_functions: list[str]):
        self.company = company
        self.category = category
        self.index = index
        self.validation_functions = list(validation_functions)

    def __str__(self):
        return f'{self.company}.CR.{self.category}.{self.index}'

    @property
    def id(self) -> str:
        return f'{self.company}.CR.{self.category}.{self.index}'


class OrderedEnum(Enum):

    def __ge__(self, other):
        if self.__class__ is other.__class__:
            return self.value >= other.value
        return NotImplemented

    def __gt__(self, other):
        if self.__class__ is other.__class__:
            return self.value > other.value
        return NotImplemented

    def __le__(self, other):
        if self.__class__ is other.__class__:
            return self.value <= other.value
        return NotImplemented

    def __lt__(self, other):
        if self.__class__ is other.__class__:
            return self.value < other.value
        return NotImplemented

class Csp(Enum):
    Aws = 1
    Azure = 2


class DataSensitivity(OrderedEnum):
    Sensitive = 2
    NonSensitive = 1


class BusinessImpact(OrderedEnum):
    High = 3
    Medium = 2
    Low = 1


class DeploymentModel(OrderedEnum):
    Private = 3
    Hybrid = 2
    Public = 1


class SecurityLevel(OrderedEnum):
    Best = 3
    Better = 2
    Good = 1


class Context:

    def __init__(self, context: Ctx = None):
        """_summary_
        Context object that will be populated by the proto project_context object. This object is based on the
        security teams context definition located in the teams component template. 
        
        Component Template: https://github.com/oak9io/oak9.cf/blob/aeab1f1bf598719c8b2d16a70c9161f61755db5a/component_mappings/COMPONENT_MAPPING_TEMPLATE.jsonc#L26
          
        Args:
            context (context_pb2): The proto context object is passed in and converted into a python object
        """

        #  Default context
        if not context:
            self.business_impact: BusinessImpact = BusinessImpact.High
            self.data_sensitivity: DataSensitivity = DataSensitivity.Sensitive
            self.deployment_model: DeploymentModel = DeploymentModel.Public
            self.security_level: SecurityLevel = SecurityLevel.Good
            self.internal_access = True
            self.external_access = False
            self.remote_access = False
            self.wireless_access = False
            self.outbound_access = False
            self.workforce = True
            self.consumers = True
            self.business_partners = True
            self.physical = False
            self.open = False
            self.limited_sensitive_data = False
            self.broad_sensitive_data = True
            self.security_privileged = True
            self.component_core = True
            self.user_interface = True
            self.management_interface = True
            return

        # Proto context object is provided
        if context.susceptibility.business_impact.lower() == "high":
            self.business_impact: BusinessImpact = BusinessImpact.High
        elif context.susceptibility.business_impact.lower() == "medium":
            self.business_impact: BusinessImpact = BusinessImpact.Medium
        else:
            self.business_impact: BusinessImpact = BusinessImpact.Low

        if context.susceptibility.data_sensitivity.lower() == "businesssensitive":
            self.data_sensitivity = DataSensitivity.Sensitive
        else:
            self.data_sensitivity = DataSensitivity.NonSensitive

        if context.app_architecture.deployment_model.lower() == "private":
            self.deployment_model: DeploymentModel = DeploymentModel.Private
        elif context.app_architecture.deployment_model.lower() == "hybrid":
            self.deployment_model: DeploymentModel = DeploymentModel.Hybrid
        else:
            self.deployment_model: DeploymentModel = DeploymentModel.Public

        if context.security_architecture.security_level.lower() == "better":
            self.security_level: SecurityLevel = SecurityLevel.Better
        elif context.security_architecture.security_level.lower() == "best":
            self.security_level: SecurityLevel = SecurityLevel.Best
        else:
            self.security_level: SecurityLevel = SecurityLevel.Good

        self.internal_access = context.accessibility.access_type.internal_access.lower() == "required"
        self.external_access = context.accessibility.access_type.external_access.lower() == "required"
        self.remote_access = context.accessibility.access_type.remote_access.lower() == "required"
        self.wireless_access = context.accessibility.access_type.wireless_access.lower() == "required"
        self.outbound_access = context.accessibility.access_type.outbound_access.lower() == "required"

        self.workforce = context.accessibility.end_users.workforce.lower() == "required"
        self.consumers = context.accessibility.end_users.consumers.lower() == "required"
        self.business_partners = context.accessibility.end_users.business_partners.lower() == "required"

        self.physical = context.accessibility.level_of_access.physical.lower() == "required"
        self.open = context.accessibility.level_of_access.open.lower() == "required"
        self.limited_sensitive_data = context.accessibility.level_of_access.limited_sensitive_data.lower() == "required"
        self.broad_sensitive_data = context.accessibility.level_of_access.broad_sensitive_data.lower() == "required"
        self.security_privileged = context.accessibility.level_of_access.security_privileged.lower() == "required"

        self.component_core = context.accessibility.applicable_component_slices.component_core.lower() == "required"
        self.user_interface = context.accessibility.applicable_component_slices.user_interface.lower() == "required"
        self.management_interface = \
            context.accessibility.applicable_component_slices.management_interface.lower() == "required"

    def is_externally_accessible(self):
        if self.external_access and not self.internal_access:
            return True

        return False

    def is_data_sensitive(self):
        if self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        return False

    def is_impact_high(self):

        if self.business_impact == BusinessImpact.High:
            return True

        return False

    def is_impact_moderate(self):

        if self.business_impact == BusinessImpact.Medium:
            return True

        return False

    def is_impact_low(self):

        if self.business_impact == BusinessImpact.Low:
            return True

        return False

    def is_business_critical(self):

        if self.business_impact == BusinessImpact.High and self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        else:
            return False

    def is_impact_high_or_data_sensitive(self):

        if self.business_impact == BusinessImpact.High or self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        else:
            return False

    def is_sensitive(self):
        if self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        else:
            return False

    def is_sensitive_and_external(self):

        if self.data_sensitivity == DataSensitivity.Sensitive and self.external_access:
            return True
        else:
            return False

    def is_sensitive_and_internal(self):
        if self.data_sensitivity == DataSensitivity.Sensitive and self.internal_access:
            return True
        else:
            return False

    def determine_severity(self):

        if self.business_impact == BusinessImpact.High:
            config_violation_severity = Severity.High

        elif self.business_impact == BusinessImpact.Medium:
            config_violation_severity = Severity.Moderate

        else:
            config_violation_severity = Severity.Low

        return config_violation_severity


Default_Context = Context()


class BlueprintType(Enum):
    Component = 1
    Reference = 2
    Solution = 3
    Resource = 4
    Customer = 5



@dataclass
class Resource:
    id: str
    name: str
    csp: Csp
    resource_type: ClassVar[str]
    id: str
    name: str
    blueprint_id: str


class WellDoneRating(OrderedEnum):
    Amazing = 4
    Great = 3
    Good = 2
    Ok = 1


class Severity(OrderedEnum):
    Critical = 4
    High = 3
    Moderate = 2
    Low = 1


class RelatedConfig:
    """
    Related Configs allows the Violation to bundle additional configurations that don't need a separate violation
    and should be remediated together
    """
    config_id: str = ""
    config_value: Union[List, int, str] = ""
    preferred_value: Union[List, int, str] = ""
    comment: str = ""


class Violation:
    """
        Defines a violation object.
        This object is DEPRECATED and is only there for backwards compatibility
        Note that there are required and optional fields

        config_gap, config_impact, config_fix and oak9_guidance are all fields that support
        a specific markup for displaying design gaps correctly to the end user.  See link here:
        https://oak9.atlassian.net/wiki/spaces/SEC/pages/351240193/Violation+Markup+Support

    """

    def __init__(
            self,
            severity: Severity = Severity.Low,
            adjusted_severity: Severity = None,
            config_id: str = "",
            config_value: str = "",
            config_gap: str = "",
            config_impact: str = "",
            config_fix: str = "",
            preferred_value: Union[List, str, int] = "",
            additional_guidance: str = "",
            documentation: str = "",
            related_configs: List[RelatedConfig] = None,
            capability_id: str = "",
            capability_name: str = "",
            priority: int = 0
    ):

        # Severity of the violation.  Default to low. Severity should be determined based on the business context
        # Resource blueprints can also specify adjusted severity. When an adjusted severity is specified, it does
        # not allow the Component blueprint to set the severity for this violation.
        # Blueprint Author: REQUIRED
        self._severity = severity

        # Adjusted severity of the violation. This field is used by Resource blueprints to set the severity in a way
        # that higher level component or resource blueprints cannot modify.  This is to account for use-cases
        # it is clear from the resource blueprint that a mitigating design is in place so the resource blueprint can
        # account for that to force a severity
        # Blueprint Author: REQUIRED (Internal blueprint use only - this configuration does not get
        # propagated to the platform)
        self._adjusted_severity = adjusted_severity

        # the unique id (full path) of the configuration that has the issue
        # e.g. LoadBalancer.listeners[0].listenerCertificates[2].certificate[1].name
        # This field should be auto-populated using a utility function (get_config_id)
        # Blueprint Author: REQUIRED
        self.config_id = config_id

        # currently configure value of this configuration
        # Blueprint Author: REQUIRED
        if type(config_value) != str:
            self.config_value = str(config_value)

        else:
            self.config_value = config_value

        # Config gap is a description of the gap if the configuration(s) are
        # not set to the preferred values
        # See: https://oak9.atlassian.net/wiki/spaces/SEC/pages/243892225/Design+Gap+-+Hierarchy+and+Logic
        # config gaps should summarize the gap and possibly list the parent configuration that needs to be updated
        # Blueprint Author: OPTIONAL
        self.config_gap = config_gap

        # Document the impact of not fixing this violation
        # Blueprint Author: OPTIONAL
        self.config_impact = config_impact

        # Provide guidance on how to fix the issue
        # Blueprint Author: OPTIONAL
        self.config_fix = config_fix

        # oak9's preferred value
        # preferred values can be strings, integers, bools, lists, dictionaries
        # the platform is responsible for checking type to use-cases like remediation
        # or displaying design gaps
        # Blueprint Author: OPTIONAL (required for remediation)
        if type(preferred_value) == list:
            self.preferred_value = ', '.join(preferred_value)

        elif type(preferred_value) != str:
            self.preferred_value = str(preferred_value)

        else:
            self.preferred_value = preferred_value

        # Additional guidance (renamed from oak9 guidance)
        # Blueprint Author: OPTIONAL (required for remediation)
        self.additional_guidance = additional_guidance

        # Related configurations that should be remediated together and
        # are better presented bundled together
        # Blueprint Author: OPTIONAL
        self.related_configs: List[RelatedConfig] = related_configs

        """
        Configurations that are autopopulated and not populated by the blueprint author
        (Some could be populated in the Customer SaC use-case
        """

        # oak9 detailed requirement id
        # REQUIRED (for all oak9 blueprints)
        self._capability_id = capability_id

        # oak9 detailed requirement name
        # This is automatically populated on the platform side
        # In the future, we may use this for customer created blueprints
        self._capability_name = capability_name

        # add documentation link
        # This does not need to be populated
        # This will be auto-populated on the platform side
        self._documentation = documentation

        # Priority of finding to relatively prioritize across
        # qualitative ratings
        self._priority = priority

    @property
    def severity(self) -> Severity:
        return self._severity

    @severity.setter
    def severity(self, value):
        if self._adjusted_severity:
            self._severity = self._adjusted_severity
        else:
            self._severity = value

    @property
    def adjusted_severity(self):
        return self._adjusted_severity

    @adjusted_severity.setter
    def adjusted_severity(self, value):
        self._adjusted_severity = value

    @property
    def documentation(self):
        return self._documentation

    @property
    def capability_id(self):
        return self._capability_id

    @capability_id.setter
    def capability_id(self, value):
        self._capability_id = value

    @property
    def capability_name(self):
        return self._capability_name

    @capability_name.setter
    def capability_name(self, value):
        self._capability_name = value

    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        if isinstance(value, int) and 101 > value > 0:
            self._priority = value


@dataclass
class DesignGap:
    # What is the  gap
    # Blueprint Author: OPTIONAL (For oak9 req ids only)
    capability_gap: str = ""
    # What is the impact
    # Blueprint Author: OPTIONAL (For oak9 req ids only)
    capability_impact: str = ""
    # severity of the design gap
    _severity: Severity = Severity.Low
    # List of violations
    violations: List[Violation] = field(default_factory=list)

    def add_violation(self, violations: List[Violation]):
        self.violations.extend(violations)
        self._update_severity()

    def _update_severity(self):
        for viol in self.violations:
            if viol.severity > self._severity:
                self._severity = viol.severity


class FindingType(Enum):
    DesignGap = 1
    Kudos = 2
    Warning = 3
    Task = 4
    ResourceGap = 5


class Finding:
    """
        Defines a observation object.
        Observations can be Violations, ResourceGaps or Passed Checks
        Note that there are required and optional fields

        config_gap, config_impact, config_fix and oak9_guidance are all fields that support
        a specific markup for displaying design gaps correctly to the end user.  See link here:
        https://oak9.atlassian.net/wiki/spaces/SEC/pages/351240193/Violation+Markup+Support

    """

    def __init__(
            self,
            finding_type: FindingType,
            desc: str,
            rating: Union[Severity, WellDoneRating] = Severity.Low,
            adjusted_severity: Severity = None,
            config_id: str = "",
            current_value: str = "",
            fix: str = "",
            preferred_value="",
            additional_guidance: str = "",
            related_configs: List[RelatedConfig] = None,
            related_findings: List[uuid.UUID] = None,
            req_id: str = "",
            req_name: str = "",
            priority: int = 0,
            documentation_url=""
    ):
        """
        Type of observation
        """

        self._id = uuid.uuid4()

        self._finding_type: FindingType = finding_type

        # For Design Gaps and Tasks: Severity of the gap or task.  Default to low. Severity should be determined based on the business context
        # Resource blueprints can also specify adjusted severity. When an adjusted severity is specified, it does
        # not allow the Component blueprint to set the severity for this violation.
        # For Kudos: Well done rating. Should be determined based on the business context
        # For Warnings: N/A
        self._rating = rating

        # Internal blueprint use only (this configuration does not get propagated to the platform)
        # Adjusted severity of the design gap. This field is used by Resource blueprints to set the severity in a way
        # that higher level component or resource blueprints cannot modify.  This is to account for use-cases
        # it is clear from the resource blueprint that a mitigating design is in place so the resource blueprint can
        # account for that to force a severity
        self._adjusted_severity = adjusted_severity

        # the unique id (full path) of the configuration that we want to call out
        # e.g. LoadBalancer.listeners[0].listenerCertificates[2].certificate[1].name
        # This field should be auto-populated using a utility function (get_config_id)
        self._config_id = config_id

        # currently configured value of this configuration
        if type(current_value) != str:
            self._current_value = str(current_value)
        else:
            self._current_value = current_value

        # For design gaps - Description of the gap to be fixed.
        # Note that design gaps can also use the gap field to populate the gap
        # For Kudos - Description of the passed check
        # For Tasks - Description of the task
        # For Warnings - Description of the warnings
        self._desc = desc

        # Specific details on the gap (for cases where the gap gets displayed separately)
        self._fix = fix

        # oak9's preferred value
        # preferred values can be strings, integers, bools, lists, dictionaries
        # the platform is responsible for checking type to use-cases like remediation
        # or displaying design gaps
        # (Required for remediation)
        if type(preferred_value) == list:
            self._preferred_value = ', '.join(preferred_value)

        elif type(preferred_value) != str:
            self._preferred_value = str(preferred_value)

        else:
            self._preferred_value = preferred_value

        # Additional guidance
        self._additional_guidance = additional_guidance

        # Related configurations that should be remediated together or
        # are better presented bundled together
        self._related_configs: List[RelatedConfig] = related_configs or []

        # add documentation link
        # Currently this is auto-populated on the platform side
        self._documentation_url = documentation_url

        # Requirement id
        # Could be oak9 or customer provided requirement id
        self._req_id = req_id

        # oak9 detailed requirement name
        # This is automatically populated on the platform side
        self._req_name = req_name

        # Priority of finding to relatively prioritize across
        # qualitative ratings.  Can be any number from 0-100
        self._priority = priority

        # Related findings
        # List of UUIDs for related findings
        self._related_findings = related_findings or []

    @property
    def id(self):
        return self._id

    @property
    def finding_type(self):
        return self._finding_type

    @finding_type.setter
    def finding_type(self, value):
        self._finding_type = value

    @property
    def rating(self):
        return self._rating

    @rating.setter
    def rating(self, value):
        self._rating = value

    @property
    def config_id(self):
        return self._config_id

    @config_id.setter
    def config_id(self, value):
        self._config_id = value

    @property
    def current_value(self):
        return self._current_value

    @current_value.setter
    def current_value(self, value):
        self._current_value = value

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value

    @property
    def fix(self):
        return self._fix

    @fix.setter
    def fix(self, value):
        self._fix = value

    @property
    def preferred_value(self):
        return self._preferred_value

    @preferred_value.setter
    def preferred_value(self, value):
        if type(value) == list:
            self._preferred_value = ', '.join(value)
        elif type(value) != str:
            self._preferred_value = str(value)
        else:
            self._preferred_value = value

    @property
    def additional_guidance(self):
        return self.additional_guidance

    @additional_guidance.setter
    def additional_guidance(self, value):
        self._additional_guidance = value

    @property
    def severity(self) -> Severity:
        return self._rating

    @severity.setter
    def severity(self, value):
        if self._adjusted_severity:
            self._rating = self._adjusted_severity
        else:
            self._rating = value

    @property
    def adjusted_severity(self):
        return self._adjusted_severity

    @adjusted_severity.setter
    def adjusted_severity(self, value):
        self._adjusted_severity = value

    @property
    def capability_id(self):
        return self._req_id

    @capability_id.setter
    def capability_id(self, value):
        self._req_id = value

    @property
    def capability_name(self):
        return self._req_name

    @capability_name.setter
    def capability_name(self, value):
        self._req_name = value

    @property
    def req_id(self):
        return self._req_id

    @req_id.setter
    def req_id(self, value):
        # TODO: add checks for customer provided ids vs oak9 ids
        self._req_id = value

    @property
    def req_name(self):
        return self._req_name

    @req_name.setter
    def req_name(self, value):
        # TODO: add checks for customer provided reqs vs oak9 reqs
        self._req_name = value

    @property
    def related_configs(self):
        return self._related_configs

    def add_related_config(self, related_config: RelatedConfig):
        self._related_configs.append(related_config)

    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        if isinstance(value, int) and 101 > value > 0:
            self._priority = value

    @property
    def related_findings(self):
        return self._related_findings

    @property
    def documentation_url(self):
        return self._documentation_url

    @documentation_url.setter
    def documentation_url(self, value):
        self._documentation_url = value

    def add_related_findings(self, related_findings: Union[uuid.UUID, List]):
        if isinstance(related_findings, uuid.UUID):
            self._related_findings.append(related_findings)
        elif isinstance(related_findings, list):
            for finding in related_findings:
                if isinstance(related_findings, uuid.UUID):
                    self._related_findings.append(finding)

    @classmethod
    def from_violation(cls, viol: Violation):
        self = cls.__new__(cls)
        self._finding_type = FindingType.DesignGap
        self._desc = viol.config_gap
        self._rating = viol.severity
        self._adjusted_severity = viol.adjusted_severity
        self._config_id = viol.config_id
        self._current_value = viol.config_value
        self._desc = viol.config_fix
        self._preferred_value = viol.preferred_value
        self._additional_guidance = viol.additional_guidance
        self._documentation_url = viol.documentation
        self._related_configs = viol.related_configs or []
        self._req_id = viol.capability_id
        self._req_name = viol.capability_name
        self.priority = viol.priority
        return self


    def to_violation(self):
        viol = Violation()
        if self.finding_type not in [FindingType.DesignGap, FindingType.ResourceGap]:
            return None

        viol.config_gap = self.desc
        viol.severity = self.rating
        viol.adjusted_severity = self.adjusted_severity
        viol.config_id = self.config_id
        viol.config_value = self.current_value
        viol.config_fix = self.fix
        viol.preferred_value = self.preferred_value
        viol.additional_guidance = self.additional_guidance
        viol._documentation = self.documentation_url
        viol.related_configs = self.related_configs
        viol.capability_id = self.req_id
        viol.capability_name = self.req_name
        viol.priority = self.priority

        return viol

    def __str__(self):
        ret_str = ''
        ret_str += f"{Style.BRIGHT}Finding Type{Style.NORMAL}: {self.finding_type}\n"
        if self.finding_type in [FindingType.DesignGap, FindingType.ResourceGap, FindingType.Task]:
            ret_str += f"{Style.BRIGHT}Severity{Style.NORMAL}: {self.severity}\n"
            ret_str += f"{Style.BRIGHT}Action Required{Style.NORMAL}: {self.desc}\n"
            ret_str += f"{Style.BRIGHT}Fix{Style.NORMAL}: {self.fix}\n" if self.fix else ''
        elif self.finding_type == FindingType.Kudos:
            ret_str += f"{Style.BRIGHT}Rating{Style.NORMAL}: {self.rating}\n"
            ret_str += f"{Style.BRIGHT}Description{Style.NORMAL}: {self.desc}\n"
        elif self.finding_type == Warning:
            ret_str += f"{Style.BRIGHT}Description{Style.NORMAL}: {self.desc}\n"
        return ret_str

@dataclass
class ValidationMetaInfo:
    caller: str
    request_id: str
    resource_type: str
    blueprint_id: str
    resource_name: str
    resource_id: str


class DesignPref:
    pass


def find_all_resources_by_type(graph: Graph, resource_type: Graph) -> List[Vertex]:
    resource_list = []
    # for root_node in graph.root_nodes:
    #     if root_node.node.vertex_type == VertexType.Resource:
    #         if root_node.node.id == resource_type:
    #             resource_list.append(root_node.node)
    #
    return resource_list


def find_resource_by_id(graph: Graph, resource_id: str) -> Vertex:
    pass


def find_resource_by_name(graph: Graph, resource_name: str) -> Vertex:
    pass


class Blueprint:
    display_name: ClassVar[str] = None
    blueprint_type: ClassVar[BlueprintType] = BlueprintType.Customer
    id: ClassVar[str] = None
    parent_blueprint_id: ClassVar[str] = None
    version: ClassVar[str] = None

    def __init__(self, graph: Any, context: Context = None, design_pref: DesignPref = None) -> None:
        self._graph = graph
        self._context = context
        self.design_pref = design_pref
        self._meta_info = None

    @property
    def context(self):
        return self._context

    @property
    def meta_info(self):
        return self._meta_info

    @meta_info.setter
    def meta_info(self, value):
        pass

    @property
    def graph(self):
        return self._graph

    def validate(self) -> Set[Finding]:
        pass


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_sql_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_sql_pb2 as gcp_dot_gcp__sql__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgcp/gcp_google_sql_bundle.proto\x12!oak9.tython.gcp.google_sql_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_sql.proto\"\xd5\x02\n\tGoogleSql\x12\x36\n\x0csql_database\x18\x01 \x03(\x0b\x32 .oak9.tython.gcp.sql.SqlDatabase\x12G\n\x15sql_database_instance\x18\x02 \x01(\x0b\x32(.oak9.tython.gcp.sql.SqlDatabaseInstance\x12`\n\"sql_source_representation_instance\x18\x03 \x01(\x0b\x32\x34.oak9.tython.gcp.sql.SqlSourceRepresentationInstance\x12\x35\n\x0csql_ssl_cert\x18\x04 \x03(\x0b\x32\x1f.oak9.tython.gcp.sql.SqlSslCert\x12.\n\x08sql_user\x18\x05 \x01(\x0b\x32\x1c.oak9.tython.gcp.sql.SqlUserb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_sql_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLESQL._serialized_start=111
  _GOOGLESQL._serialized_end=452
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EndpointsServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___EndpointsServiceXTimeouts = EndpointsServiceXTimeouts

@typing_extensions.final
class EndpointsService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ApisEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class EndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APIS_FIELD_NUMBER: builtins.int
    CONFIG_ID_FIELD_NUMBER: builtins.int
    DNS_ADDRESS_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    GRPC_CONFIG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OPENAPI_CONFIG_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROTOC_OUTPUT_BASE64_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def apis(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    config_id: builtins.str
    dns_address: builtins.str
    @property
    def endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    grpc_config: builtins.str
    id: builtins.str
    openapi_config: builtins.str
    project: builtins.str
    protoc_output_base64: builtins.str
    service_name: builtins.str
    @property
    def timeouts(self) -> global___EndpointsServiceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        apis: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_id: builtins.str = ...,
        dns_address: builtins.str = ...,
        endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        grpc_config: builtins.str = ...,
        id: builtins.str = ...,
        openapi_config: builtins.str = ...,
        project: builtins.str = ...,
        protoc_output_base64: builtins.str = ...,
        service_name: builtins.str = ...,
        timeouts: global___EndpointsServiceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apis", b"apis", "config_id", b"config_id", "dns_address", b"dns_address", "endpoints", b"endpoints", "grpc_config", b"grpc_config", "id", b"id", "openapi_config", b"openapi_config", "project", b"project", "protoc_output_base64", b"protoc_output_base64", "resource_info", b"resource_info", "service_name", b"service_name", "timeouts", b"timeouts"]) -> None: ...

global___EndpointsService = EndpointsService

@typing_extensions.final
class EndpointsServiceConsumersIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___EndpointsServiceConsumersIamBindingXCondition = EndpointsServiceConsumersIamBindingXCondition

@typing_extensions.final
class EndpointsServiceConsumersIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_PROJECT_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    consumer_project: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    service_name: builtins.str
    @property
    def condition(self) -> global___EndpointsServiceConsumersIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consumer_project: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        service_name: builtins.str = ...,
        condition: global___EndpointsServiceConsumersIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "consumer_project", b"consumer_project", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role", "service_name", b"service_name"]) -> None: ...

global___EndpointsServiceConsumersIamBinding = EndpointsServiceConsumersIamBinding

@typing_extensions.final
class EndpointsServiceConsumersIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___EndpointsServiceConsumersIamMemberXCondition = EndpointsServiceConsumersIamMemberXCondition

@typing_extensions.final
class EndpointsServiceConsumersIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_PROJECT_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    consumer_project: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    service_name: builtins.str
    @property
    def condition(self) -> global___EndpointsServiceConsumersIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consumer_project: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        service_name: builtins.str = ...,
        condition: global___EndpointsServiceConsumersIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "consumer_project", b"consumer_project", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role", "service_name", b"service_name"]) -> None: ...

global___EndpointsServiceConsumersIamMember = EndpointsServiceConsumersIamMember

@typing_extensions.final
class EndpointsServiceConsumersIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_PROJECT_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    consumer_project: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    service_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consumer_project: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        service_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer_project", b"consumer_project", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info", "service_name", b"service_name"]) -> None: ...

global___EndpointsServiceConsumersIamPolicy = EndpointsServiceConsumersIamPolicy

@typing_extensions.final
class EndpointsServiceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___EndpointsServiceIamBindingXCondition = EndpointsServiceIamBindingXCondition

@typing_extensions.final
class EndpointsServiceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    service_name: builtins.str
    @property
    def condition(self) -> global___EndpointsServiceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        service_name: builtins.str = ...,
        condition: global___EndpointsServiceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role", "service_name", b"service_name"]) -> None: ...

global___EndpointsServiceIamBinding = EndpointsServiceIamBinding

@typing_extensions.final
class EndpointsServiceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___EndpointsServiceIamMemberXCondition = EndpointsServiceIamMemberXCondition

@typing_extensions.final
class EndpointsServiceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    service_name: builtins.str
    @property
    def condition(self) -> global___EndpointsServiceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        service_name: builtins.str = ...,
        condition: global___EndpointsServiceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role", "service_name", b"service_name"]) -> None: ...

global___EndpointsServiceIamMember = EndpointsServiceIamMember

@typing_extensions.final
class EndpointsServiceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    service_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        service_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info", "service_name", b"service_name"]) -> None: ...

global___EndpointsServiceIamPolicy = EndpointsServiceIamPolicy



from abc import abstractmethod
from typing import Iterator, Dict

from core.bp_metadata_utils.policy import Policy
from core.bp_metadata_utils.policy_repo import PolicyRepo

class MultiplePoliciesPerFileRepo(PolicyRepo):

    def __init__(self, url: str, local_path='', skip_sync=False) -> None:
        """
        Constructs a repo for PolicyPerFileRepo Policies.
        """
        super(MultiplePoliciesPerFileRepo, self).__init__(
            url=url,
            local_path=local_path,
            skip_sync=skip_sync,
        )

    @abstractmethod
    def parse_policy_file(self, policy_path: str) -> Iterator[Policy]:
        """
        This method is responsible for parsing the SaC policy and converting it into a Policy object.
        param policy_path: Path to the policy stored in a repo.
        """
        pass

    @property
    def policies(self) -> Dict[str, Policy]:
        """
        Iterate over the policies in a given repo and converts them to a Policy object.
        return: A list of policies
        """
        result = {}
        for policy_path in self.policy_file_paths:
            if self.pre_filter(policy_path):
                continue

            policies = self.parse_policy_file(policy_path)
            for policy in policies:
                if not self.filter(policy):
                    result[policy.url] = policy

        return result


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CrossVersionObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___CrossVersionObjectReference = CrossVersionObjectReference

@typing_extensions.final
class HorizontalPodAutoscaler(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___HorizontalPodAutoscalerSpec: ...
    @property
    def status(self) -> global___HorizontalPodAutoscalerStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___HorizontalPodAutoscalerSpec | None = ...,
        status: global___HorizontalPodAutoscalerStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___HorizontalPodAutoscaler = HorizontalPodAutoscaler

@typing_extensions.final
class HorizontalPodAutoscalerList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HorizontalPodAutoscaler]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___HorizontalPodAutoscaler] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___HorizontalPodAutoscalerList = HorizontalPodAutoscalerList

@typing_extensions.final
class HorizontalPodAutoscalerSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_REPLICAS_FIELD_NUMBER: builtins.int
    MIN_REPLICAS_FIELD_NUMBER: builtins.int
    SCALE_TARGET_REF_FIELD_NUMBER: builtins.int
    TARGET_CPU_UTILIZATION_PERCENTAGE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    max_replicas: builtins.int
    min_replicas: builtins.int
    @property
    def scale_target_ref(self) -> global___CrossVersionObjectReference: ...
    target_cpu_utilization_percentage: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_replicas: builtins.int = ...,
        min_replicas: builtins.int = ...,
        scale_target_ref: global___CrossVersionObjectReference | None = ...,
        target_cpu_utilization_percentage: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scale_target_ref", b"scale_target_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_replicas", b"max_replicas", "min_replicas", b"min_replicas", "resource_info", b"resource_info", "scale_target_ref", b"scale_target_ref", "target_cpu_utilization_percentage", b"target_cpu_utilization_percentage"]) -> None: ...

global___HorizontalPodAutoscalerSpec = HorizontalPodAutoscalerSpec

@typing_extensions.final
class HorizontalPodAutoscalerStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_CPU_UTILIZATION_PERCENTAGE_FIELD_NUMBER: builtins.int
    CURRENT_REPLICAS_FIELD_NUMBER: builtins.int
    DESIRED_REPLICAS_FIELD_NUMBER: builtins.int
    LAST_SCALE_TIME_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    current_cpu_utilization_percentage: builtins.int
    current_replicas: builtins.int
    desired_replicas: builtins.int
    @property
    def last_scale_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    observed_generation: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        current_cpu_utilization_percentage: builtins.int = ...,
        current_replicas: builtins.int = ...,
        desired_replicas: builtins.int = ...,
        last_scale_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        observed_generation: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_scale_time", b"last_scale_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_cpu_utilization_percentage", b"current_cpu_utilization_percentage", "current_replicas", b"current_replicas", "desired_replicas", b"desired_replicas", "last_scale_time", b"last_scale_time", "observed_generation", b"observed_generation", "resource_info", b"resource_info"]) -> None: ...

global___HorizontalPodAutoscalerStatus = HorizontalPodAutoscalerStatus

@typing_extensions.final
class Scale(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ScaleSpec: ...
    @property
    def status(self) -> global___ScaleStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ScaleSpec | None = ...,
        status: global___ScaleStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Scale = Scale

@typing_extensions.final
class ScaleSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["replicas", b"replicas", "resource_info", b"resource_info"]) -> None: ...

global___ScaleSpec = ScaleSpec

@typing_extensions.final
class ScaleStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLICAS_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    replicas: builtins.int
    selector: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        replicas: builtins.int = ...,
        selector: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["replicas", b"replicas", "resource_info", b"resource_info", "selector", b"selector"]) -> None: ...

global___ScaleStatus = ScaleStatus
